#include <memory>   // std::auto_ptr
#include <iostream>

#include "citygml/CityGML.hxx"

using std::cerr;
using std::endl;

int
main (int argc, char* argv[])
{
  if (argc != 2)
  {
    cerr << "usage: " << argv[0] << " sample.xml" << endl;
    return 1;
  }

  try
  {
    using namespace citygml;

    // Read in the XML file and obtain its object model.
    //
    std::auto_ptr<CityModelType> city (CityModel (argv[1]));

    // Prepare namespace mapping and schema location information.
    //
    xml_schema::namespace_infomap map;

    map[""].name = "http://www.opengis.net/citygml/1.0";
    map["gml"].name = "http://www.opengis.net/gml";
    map["xlink"].name = "http://www.w3.org/1999/xlink";
    map["smil20lang"].name = "http://www.w3.org/2001/SMIL20/Language";
    map["smil20"].name = "http://www.w3.org/2001/SMIL20/";
    map["xAL"].name = "urn:oasis:names:tc:ciq:xsdschema:xAL:2.0";
    map["gen"].name = "http://www.opengis.net/citygml/generics/1.0";
    map["veg"].name = "http://www.opengis.net/citygml/vegetation/1.0";
    map["wtr"].name = "http://www.opengis.net/citygml/waterbody/1.0";
    map["trans"].name = "http://www.opengis.net/citygml/transportation/1.0";
    map["tex"].name = "http://www.opengis.net/citygml/texturedsurface/1.0";
    map["app"].name = "http://www.opengis.net/citygml/appearance/1.0";
    map["frn"].name = "http://www.opengis.net/citygml/cityfurniture/1.0";
    map["grp"].name = "http://www.opengis.net/citygml/cityobjectgroup/1.0";
    map["bldg"].name = "http://www.opengis.net/citygml/building/1.0";
    map["luse"].name = "http://www.opengis.net/citygml/landuse/1.0";
    map["dem"].name = "http://www.opengis.net/citygml/relief/1.0";
    map["xsi"].name = "http://www.w3.org/2001/XMLSchema-instance";

    // Write it out.
    //
    CityModel (std::cout, *city, map);
  }
  catch (const xml_schema::exception& e)
  {
    cerr << e << endl;
    return 1;
  }
}
